mpes documentation — mpes 1.1.1 documentation

# `mpes` documentation

Distributed data processing routines for multidimensional photoemission spectroscopy (MPES).

## MPES concepts

In a photoemission process, an extreme UV or X-ray photon liberates an electron from the confines of the electronic potential within the material. ARPES directly measures the electronic energy and momentum parallel to the surface of the sample under study to infer the electronic states of the material. For a tutorial review on ARPES and its applications in physics and material science, see here. The data structure of ARPES is a stack of 2D images measured at different sample geometries, which are used to reconstruct the full static 3D band structure of the material.

The MPES instrument enables sampling of the multidimensional parameter space associated with the electronic band structure at an elevated speed. At the minimum, it measures the two parallel momenta and the energy of photoelectrons simultaneously. The measurement procedure can be extended with recording of varying external parameters such as the temperature, photon polarization, dynamical time delay as in a time-resolved ARPES (trARPES) experiments using a ultrafast laser system (~ fs resolution), etc. These different flavors of momentum-resolved photoemission experiment together yield a complete understanding of the electronic properties of materials under equilibrium and nonequilibrium conditions for realistic design and simulation of electronic devices.

Instructions

- How to start
- Overview of modules
- Usage notes

API documentation

- Base classes `(mpes.base)`
- File I/O & Processing `(mpes.fprocessing)`
- Analysis `(mpes.analysis)`
- Band-mapping data classes `(mpes.bandstructure)`
- Visualization `(mpes.visualization)`
- Utility functions `(mpes.utils)`